export function mock_authorization_functions(config, app) {
    function match(tuple) {
        for (const item of config) {
            if (item.subject && item.subject !== tuple.subject)
                continue;
            if (item.action && item.action !== tuple.action)
                continue;
            if (item.object && item.object !== tuple.object)
                continue;
            return { result: item.result, reason: item.reason };
        }
        return { result: false, reason: 'No match' };
    }
    async function check_authorization(subject_or_tuple, action, object) {
        let tuples;
        if (Array.isArray(subject_or_tuple)) {
            tuples = subject_or_tuple;
            if (tuples.length === 0) {
                return [];
            }
        }
        else {
            tuples = [{ subject: subject_or_tuple, action: action, object: object }];
        }
        const result = tuples.map(match);
        if (Array.isArray(subject_or_tuple)) {
            return result.map((r) => ({
                result: r.result ?? false,
                reason: r.reason,
            }));
        }
        else {
            return { result: result[0].result ?? false, reason: result[0].reason };
        }
    }
    async function update_relations(add, remove) {
        app.authorization_mock_log = app.authorization_mock_log ?? [];
        app.authorization_mock_log.push({ add, remove });
    }
    async function relate(subject_or_tuples, relation, object) {
        let tuples;
        if (Array.isArray(subject_or_tuples)) {
            tuples = subject_or_tuples;
        }
        else {
            tuples = [{ subject: subject_or_tuples, relation: relation, object: object }];
        }
        await update_relations(tuples, []);
    }
    async function unrelate(subject_or_tuples, relation, object) {
        let tuples;
        if (Array.isArray(subject_or_tuples)) {
            tuples = subject_or_tuples;
        }
        else {
            tuples = [{ subject: subject_or_tuples, relation: relation, object: object }];
        }
        await update_relations([], tuples);
    }
    async function query(_subject, _relation, _object) {
        throw Error('Not implemented');
    }
    return { check_authorization, update_relations, relate, unrelate, query };
}
//# sourceMappingURL=mock.js.map